@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP;
 
-our $VERSION = '0.035_002'; # TRIAL VERSION
+our $VERSION = '0.036_001'; # TRIAL VERSION
 
 use YAML::PP::Schema;
 use YAML::PP::Schema::JSON;
@@ -24,7 +24,7 @@ sub new {
     my $bool = delete $args{boolean};
     $bool = 'perl' unless defined $bool;
     my $schemas = delete $args{schema} || ['+'];
-    my $cyclic_refs = delete $args{cyclic_refs} || 'allow';
+    my $cyclic_refs = delete $args{cyclic_refs} || 'fatal';
     my $indent = delete $args{indent};
     my $width = delete $args{width};
     my $writer = delete $args{writer};
@@ -590,7 +590,10 @@ Additionally you can add further schemas, for example C<Merge>.
 
 =item cyclic_refs
 
-Default: 'allow' but will be switched to fatal in the future for safety!
+Default: C<fatal> (since 0.037)
+
+Before the default was C<allow>, but this can lead to memory leaks
+when loading on untrusted data, so it was changed to C<fatal> by default.
 
 This option is for loading only.
 
@@ -1279,6 +1282,16 @@ The layout is like libyaml output:
     - - b1
       - b2
 
+=head1 FAQ
+
+=over
+
+=item Are C<<<> merge keys supported?
+
+Yes, this can be enabled optionally, see L<YAML::PP::Schema::Merge>
+
+=back
+
 =head1 WHY
 
 All the available parsers and loaders for Perl are behaving differently,
