@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Loader;
 
-our $VERSION = '0.035_002'; # TRIAL VERSION
+our $VERSION = '0.036_001'; # TRIAL VERSION
 
 use YAML::PP::Parser;
 use YAML::PP::Constructor;
@@ -12,7 +12,7 @@ use YAML::PP::Reader;
 sub new {
     my ($class, %args) = @_;
 
-    my $cyclic_refs = delete $args{cyclic_refs} || 'allow';
+    my $cyclic_refs = delete $args{cyclic_refs} || 'fatal';
     my $default_yaml_version = delete $args{default_yaml_version} || '1.2';
     my $preserve = delete $args{preserve};
     my $duplicate_keys = delete $args{duplicate_keys};
